@@ -678,6 +678,16 @@ class SlashCommands(FastAPI):
                         f"multi-value selects must be typed as a List[T] rather than T."
                     )
 
+                if origin is list:
+                    inner, *_ = typing.get_args(origin)
+                    if inner is str:
+                        options = []
+                        break
+
+                if hint is str:
+                    options = []
+                    break
+
                 options = _get_select_options(
                     typing.get_args(hint)[0] if origin is list else hint
                 )
@@ -738,7 +748,11 @@ def _get_select_options(val: typing.Any) -> List[SelectOption]:
         return option_choices
 
     if not issubclass(val, Enum):
-        raise TypeError("invalid type given expected a subclass of Enum or Literal.")
+        raise TypeError(
+            "invalid type given expected a subclass of Enum or Literal.\n"
+            "Note: you can hint as type `str` to mark the select as general component. "
+            "This means you can add options at runtime via component.with_options()."
+        )
 
     set_type = None
     for v in val:
